/*
    Prince - Fonts stylesheet
    http://www.princexml.com
*/

/* standard "serif" font family */

@font-face {
    font-family: serif;
    src: prince-lookup("Arial Unicode MS") /* last resort font */
}

@font-face {
    font-family: serif;
    src: prince-lookup("Angsana New") /* Thai script */
}

@font-face {
    font-family: serif;
    src: prince-lookup("Kartika") /* Malayalam script */
}

@font-face {
    font-family: serif;
    src: prince-lookup("Tunga") /* Kannada script */
}

@font-face {
    font-family: serif;
    src: prince-lookup("Gautami") /* Telugu script */
}

@font-face {
    font-family: serif;
    src: prince-lookup("Latha") /* Tamil script */
}

@font-face {
    font-family: serif;
    src: prince-lookup("Shruti") /* Gujarati script */
}

@font-face {
    font-family: serif;
    src: prince-lookup("Raavi") /* Gurmukhi script */
}

@font-face {
    font-family: serif;
    src: prince-lookup("Vrinda") /* Bengali script */
}

@font-face {
    font-family: serif;
    src: prince-lookup("Mangal") /* Devanagari script */
}

@font-face {
    font-family: serif;
    src: prince-lookup("Batang") /* Korean */
}

@font-face {
    font-family: serif;
    unicode-range: U+3040-309F, U+30A0-30FF, U+4E00-9FBF;
    src: prince-lookup("MS Mincho") /* Japanese */
}

@font-face {
    font-family: serif;
    src: prince-lookup("MingLiU") /* CJK ideographs */
}

@font-face {
    font-family: serif;
    src: prince-lookup("Symbol")
}

@font-face {
    font-family: serif;
    src: prince-lookup("Times New Roman")
}

/* standard "sans-serif" font family */

@font-face {
    font-family: sans-serif;
    src: prince-lookup("Dotum") /* Korean */
}

@font-face {
    font-family: sans-serif;
    unicode-range: U+3040-309F, U+30A0-30FF, U+4E00-9FBF;
    src: prince-lookup("MS Gothic") /* Japanese */
}

@font-face {
    font-family: sans-serif;
    src: prince-lookup("Arial")
}

/* standard "monospace" font family */

@font-face {
    font-family: monospace;
    src: prince-lookup("Courier New")
}

/* standard "cursive" font family */

@font-face {
    font-family: cursive;
    src: prince-lookup("Comic Sans MS")
}

/* standard "fantasy" font family */

@font-face {
    font-family: fantasy;
    src: prince-lookup("Comic Sans MS")
}

